import QtQuick 1.1
import "components"

Rectangle {
    id: rectangle1
    width: 640
    height: 480

    gradient: Gradient {
        GradientStop {
            position: 0.16
            color: "#afacac"
        }

        GradientStop {
            position: 1
            color: "#000000"
        }
    }

    Text {
        id: text1
        x: 57
        y: 16
        text: qsTr("Latitude")
        font.family: "DejaVu Sans"
        font.pixelSize: 17
    }

    NumericSelector {
        id: latitudeDegrees
        x: 132
        y: 8
        height: 36
        textFontFamily: "DejaVu Sans"
        value: 2
        precision: 0
        width: 104
        max: 360
        min: -360
        increment: 1
        displayText: qsTr("<sup>o</sup>")
    }

    NumericSelector {
        id: latitudeMinSec
        x: 248
        y: 8
        height: 36
        textFontFamily: "DejaVu Sans"
        width: 110
        max: 100
        min: 0
        autoRepeatInterval: 2
        increment: 0.01
        precision: 2
    }



    AlphaField {
        id: alphabetic_field1
        x: 137
        y: 121
        width: 197
        height: 26
        fieldSpacing: 6
        inputText: " John Doe"
        keyTextColor: "#ffffff"
        keyTextFontSize: 13
        keyTextBold: true
        inputColor: "#ffffff"
        labelColor: "#000000"
        inputFontPixelSize: 14
        keyboardAnimationSpeed: 100
        inputFontFamily: "DejaVu Sans"
        labelFontFamily: "DejaVu Sans"
        labelFontPixelSize: 14
        labelText: "Name"
    }

    PanelReadOut {
        id: panel_read_out1
        x: 18
        y: 245
        width: 211
        height: 99
        text: "10000"
        font.pixelSize: 22
        textColor: "#50dd0e"
        imagePanel: "images/bezel.bmp"
        font.bold: false
        font.family: "DejaVu Sans"
    }

    Speedometer {
        id: spedometer1
        x: 241
        y: 233
        width: 210
        height: 210
        needleImage: "images/needle.png"
        overlayImageHeight: 105
        min: 0
        needleImageHeight: 63
        overlayImage: "images/overlay.png"
        value: 21
        needleImageWidth: 8
        max: 120
        needleRotationY: 65
        needleRotationX: 5
        maxAngle: 133
        overlayY: 18
        overlayImageWidth: 148
        overlayX: 21
        needleY: 33
        needleX: 98
        backgroundImage: "images/meterbackground.png"        
    }

    Image{
        x: 476
        y: 252
        source: "images/battery_base.png"

        VerticalLevelIndicator {
            id: vertical2
            x: 4
            y: 32
            width: 128
            height: 149
            hintFontBold: true
            minValue: 0
            hintFontPixelSize: 24
            valueScale: 2.0
            symbol: "%"
            imageBase: "images/battery_full.png"
            hintFontColor: "#000000"
            value: 36
            showHint: true
            imageOverlay: "images/battery_empty.png"
            maxValue: 50
            increment: 3
            startPosition: "bottom"
            hintFontFamily: "DejaVu Sans"
        }
    }

    LEDLight {
        id: led_light1
        x: 86
        y: 163
        width: 60
        height: 60
        on: false
        font.pixelSize: 12
        textColor: "#000000"
        textPosition: "bottom"
        label: "Label"
        fieldSpacing: 6
        font.bold: false
        font.family: "DejaVu Sans"
        imageOff: "images/ledoff.png"
        imageOn: "images/ledon.png"
    }

    NumericField {
        id: numeric_field1
        x: 137
        y: 76
        width: 190
        height: 26
        fieldSpacing: 15
        inputText: ""
        keyTextColor: "#ffffff"
        inputColor: "#ffffff"
        labelColor: "#000000"
        inputFontPixelSize: 14
        keyboardAnimationSpeed: 100
        inputFontFamily: "DejaVu Sans"
        labelFontFamily: "DejaVu Sans"
        labelFontPixelSize: 14
        labelText: "Latitude"
        min: 0
        max: 100
        maskedInput: "999.99;_"
    }

    VerticalNumericField {
        id: numeric_field___vertical1
        x: 408
        y: 16
        width: 156
        height: 63
        maskedInput: "(999) 999-9999;_"
        max: 100
        fieldSpacing: 6
        min: 0
        inputText: ""
        keyTextColor: "#ffffff"
        inputColor: "#ffffff"
        labelColor: "#000000"
        inputFontPixelSize: 14
        keyboardAnimationSpeed: 100
        inputFontFamily: "DejaVu Sans"
        labelFontFamily: "DejaVu Sans"
        labelFontPixelSize: 14
        labelText: "Phone"
    }

    Knob {
        id: knob2
        x: 408
        y: 85
        width: 156
        height: 142
        hintBorderColor: "#000000"
        imageNeedleHeight: 108
        imageBase: "images/dialbase.png"
        showHint: true
        hintBorderWidth: 2
        hintFontFamily: "DejaVu Sans"
        imageNeedle: "images/dialneedle.png"
        hintBackgroundColor: "#ffffff"
        hintFontColor: "#000000"
        hintFontPixelSize: 16
        remove: false
        initialIndex: 0
        mouseAreaWidth: 77
        mouseAreaHeight: 77
        textColor: "#ffffff"
        imageNeedleWidth: 108
        font.family: "DejaVu Sans"
        imageBaseHeight: 108
        font.bold: false
        hintRadius: 9
        imageBaseWidth: 108
        add: false
        hintWidth: 40
        font.pixelSize: 13
        hintHeight: 40
        model: ListModel {
            id: data
            ListElement {
                index: 0
                value: 0
            }

            ListElement {
                index: 1
                value: 1
            }

            ListElement {
                index: 2
                value: 2
            }

            ListElement {
                index: 3
                value: 3
            }

            ListElement {
                index: 4
                value: 4
            }

            ListElement {
                index: 5
                value: 5
            }
        }

        onIndexChanged: console.debug(knobValue)
    }

    function getRandomInt (min, max) {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }

    Component.onCompleted :{
        var src = "import QtQuick 1.1; Timer {id: timer1; interval: 500; running: true; repeat: true; onTriggered:{led_light1.on = !led_light1.on; panel_read_out1.text = getRandomInt(0, 10000);} }";
        var component = Qt.createQmlObject(src, rectangle1, "timerObject");

        component.start();
    }
}



